#################
ctrl_bps_htcondor
#################

``ctrl_bps_htcondor`` is a package in the `LSST Science Pipelines <https://pipelines.lsst.io>`_.

HTCondor plugin for LSST PipelineTask execution framework.
